# PyMin

### pymin (0.0.0)

A command-line interface tool for checking PyPI package name availability with rich output formatting and validation rules.


# Features

## Core Features

1. Package Name Validation
   - Real-time PyPI availability check
   - PEP 503 naming convention validation
   - Standardized name formatting
   - Typosquatting detection

2. Rich User Interface
   - Color-coded status indicators
   - Interactive progress display
   - Formatted results presentation
   - Visual validation markers

3. Developer Experience
   - Intuitive command structure
   - Comprehensive error messages
   - Real-time feedback
   - Multiple command aliases


# Installation

## Quick Start

Install via pipx:
```bash
$ pipx install pymin
```

### System Requirements
| Component | Requirement                |
|-----------|----------------------------|
| Python    | >=3.8 |
| OS        | Platform independent       |


# Usage

## Command Interface

The CLI provides two command interfaces:

| Command | Description         |
|---------|---------------------|
| pymin   | Main command        |
| pm      | Short alias         |

### Basic Usage
```bash
❯ pymin
🔍 PyPI Package Name Checker

# or using alias
❯ pm
🔍 PyPI Package Name Checker
```

### Available Commands
| Command | Description                       |
|---------|---------------------------------- |
| check   | Validate package name availability|
| search  | Find similar package names        |

### Command Examples

#### Check Package Name
```bash
$ pymin check my-package-name
┌─ PyPI Package Name Check Results ─┐
│ Package Name: my-package-name     │
│ Normalized Name: my-package-name  │
│ Valid Format: ✓                   │
│ Available: ✓                      │
│ Message: Package name available!  │
└───────────────────────────────────┘
```

#### Search Similar Names
```bash
# Default similarity (80%)
$ pm search fastapi

# Custom similarity threshold
$ pm search fastapi --threshold 0.85
```

### Command Options
| Command | Option      | Description                        | Type  | Default |
|---------|-------------|------------------------------------| ------|---------|
| check   | name        | Target package name to validate    | str   | -       |
| search  | name        | Package name to search for         | str   | -       |
| search  | --threshold | Similarity threshold (0.0-1.0)     | float | 0.8     |


# License

This project is licensed under the MIT License.


# Project Structure

```
pymin/
├── src/
│   └── pypi_toolkit/
│       ├── check.py       # Package name validation service with PyPI availability checking and security analysis
│       ├── cli.py         # Command-line interface providing PyPI package name validation and search functionality
│       ├── packaging.py   # Package version validation service using PEP 440 standards
│       ├── search.py      # Package name similarity search service with PyPI integration
│       ├── security.py    # Security service for package name typosquatting detection and analysis
│       ├── similarity.py  # String similarity analysis service for package name comparison
│       ├── utils.py       # Utility functions for package name normalization and string manipulation
│       └── validators.py  # Package name validation service implementing PyPI naming conventions
├── LICENSE
├── pyproject.toml
├── readgen.toml
└── README.md
```


---
> This document was automatically generated by [ReadGen](https://github.com/TaiwanBigdata/readgen).
